.. Pyosmium documentation master file, created by
   sphinx-quickstart on Tue Mar 10 18:09:49 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pyosmium's documentation!
====================================

Pyosmium is a library to process OSM files in different formats. It is
a wrapper of the C++ library `osmium <http://osmcode.org/libosmium/>`_
and profits from its fast implementation.

.. toctree::
   :maxdepth: 2

   intro
   reference
   tools
    

* :ref:`genindex`
* :ref:`search`

